-- fichier p_e_sortie-ecran.adb
-- D. Feneuille
------------------------------------------------------------------------

with Ada.Text_Io;
use  Ada.Text_Io;

package body P_E_Sortie.Ecran is

   package Es_Entier is new Integer_Io (Integer);
   use     Es_Entier;

   ---------------------------------
   -- codes ANSI des couleurs.
   ---------------------------------
   --  Couleur   du texte   du fond
   --  -------   --------   -------
   --  Noir         30        40
   --  Rouge        31        41
   --  Vert         32        42
   --  Jaune        33        43
   --  Bleu         34        44
   --  Magenta      35        45
   --  Cyan         36        46
   --  Blanc        37        47
   ---------------------------------

   type T_Code_Couleur is array (T_Couleur) of Positive; 

   Code_Texte : constant T_Code_Couleur := (30, 31, 32, 33, 34, 35, 36, 37);  
   Code_Fond  : constant T_Code_Couleur := (40, 41, 42, 43, 44, 45, 46, 47);  

   -------------------------------------------------------------
   -- codes ANSI des attributs de texte.
   -------------------------------------------------------------
   --  Aucun attribut     0
   --  Gras               1
   --  Soulign           4  (moniteurs monochromes uniquement)
   --  Clignotant         5
   --  Vido inverse      7
   --  Cach              8
   -------------------------------------------------------------
   type T_Code_Attribut is array (T_Attribut) of Natural; 

   Code_Attribut : constant T_Code_Attribut := (0, 1, 5, 7, 8);  


   ----------------------
   -- Changer_Attribut --
   ----------------------
   procedure Changer_Attribut (
         Attribut : in     T_Attribut ) is 
   begin
      Put (Ascii.Esc);
      Put ("[");
      Put (Code_Attribut(Attribut), 1);
      Put ('m');
   end Changer_Attribut;

   ---------------------
   -- Changer_Couleur --
   ---------------------

   procedure Changer_Couleur (
         Couleur_Texte : in     T_Couleur;        
         Couleur_Fond  : in     T_Couleur := Noir ) is 
   begin
      Put (Ascii.Esc);
      Put ("[");
      Put (Code_Texte(Couleur_Texte), 2);
      Put (';');
      Put (Code_Fond(Couleur_Fond), 2);
      Put ('m');
   end Changer_Couleur;

   ---------------
   -- Clear_Cls --
   ---------------

   procedure Clear_Cls is 
   begin
      Put (Ascii.Esc);
      Put ("[2J");
   end Clear_Cls;

   --------------------
   -- Placer_Curseur --
   --------------------

   procedure Placer_Curseur (
         Ligne   : in     T_Hauteur; 
         Colonne : in     T_Largeur  ) is 
   begin
      Put (Ascii.Esc);
      Put ("[");
      Put (Ligne, 1);
      Put (';');
      Put (Colonne, 1);
      Put ('f');
   end Placer_Curseur;

end P_E_Sortie.Ecran;

