-- fichier p_e_sortie-ecran.ads
-- D. Feneuille
------------------------------------------------------------------------
-- Objectif : 
--    Offrir quelques services de gestion d'un cran qui mule un
--    terminal de type ANSI, dont:
--    - Effacement de l'cran
--    - Manipulation du curseur.
--    - Changement de couleurs et d'attributs de textes.
------------------------------------------------------------------------
-- Attention  : Le pilote de reconnaissance des squences ANSI doit tre
--   pralablement charg au dmarrage de l'ordinateur.
--   La ligne suivante doit tre ajoute dans le
--   fichier de configuration CONFIG.SYS:
--                
--   device=[RpertoireDuPilote]ansi.sys
--
--   o "[RpertoireDuPilote]" est l'emplacement physique sur le
--   disque du pilote ANSI.SYS.
--
--   Exemple: device=c:\windows\command\ansi.sys 

package P_E_Sortie.Ecran is


   ---------------------------------------------------------
   -- Gestion du Curseur
   ---------------------------------------------------------
   -- constantes qui prcisent les coordonnes du curseur 
   ---------------------------------------------------------

   C_Min_Hauteur : constant := 1;  
   -- position de la premire ligne. 
   C_Max_Hauteur : constant := 25;  
   -- position de la dernire ligne. 
   C_Min_Largeur : constant := 1;  
   -- position de la premire colonne. 
   C_Max_Largeur : constant := 80;  
   -- position de la dernire colonne. 
   subtype T_Hauteur is Positive
      range C_Min_Hauteur .. C_Max_Hauteur;
   subtype T_Largeur is Positive
      range C_Min_Largeur .. C_Max_Largeur;

   ---------------------------------------------------------
   -- Gestion de la couleur du texte et du fond d'cran.
   ---------------------------------------------------------

   type T_Couleur is 
         (Noir,    
          Rouge,   
          Vert,    
          Jaune,   
          Bleu,    
          Magenta, 
          Cyan,    
          Blanc); 

   ---------------------------------------------------------
   -- Gestion des attributs de texte.
   ---------------------------------------------------------

   type T_Attribut is 
         (Normal,     
          Gras,       
          Clignotant, 
          Inverse,    
          Cache); 


   -- ======================================================
   -- procdure Clear_Cls
   -- ------------------------------------------------------
   -- but         : Effacer tous les caractres de l'cran et
   --               positionner le curseur en position (1,1).
   -- ------------------------------------------------------
   -- paramtres  : aucun.
   -- ======================================================

   procedure Clear_Cls; 


   -- ==============================================================
   -- procdure Placer_Curseur
   -- ------------------------------------------------------
   -- but         : positionner le curseur  un endroit
   --               prcis de l'cran en prcisant la 
   --               coordonne (ligne, colonne).
   -- ------------------------------------------------------
   -- paramtres  :
   -- 
   --    ligne   : ligne  laquelle le curseur doit tre plac
   --    colonne : colonne  laquelle le curseur doit tre plac
   -- ==============================================================

   procedure Placer_Curseur (
         Ligne   : in     T_Hauteur; 
         Colonne : in     T_Largeur  ); 


   -- ======================================================
   -- procdure Changer_Couleur
   -- ------------------------------------------------------
   -- but         : Changer la couleur du texte et du fond
   --               d'cran pour les affichages  venir.
   -- ------------------------------------------------------
   -- paramtres  :
   -- 
   --    couleur_texte : nouvelle couleur du texte.
   --    couleur_fond  : nouvelle couleur du fond d'cran.
   --                      par dfaut: Noir.
   -- ======================================================

   procedure Changer_Couleur (
         Couleur_Texte : in     T_Couleur;        
         Couleur_Fond  : in     T_Couleur := Noir ); 


   -- ======================================================
   -- procdure Changer_Attribut
   -- ------------------------------------------------------
   -- but         : Changer l'attribut du texte pour les 
   --               prochains affichages.
   -- ------------------------------------------------------
   -- paramtres  :
   -- 
   --    attribut : nouvel attribut du texte.
   -- ======================================================

   procedure Changer_Attribut (
         Attribut : in     T_Attribut ); 


end P_E_Sortie.Ecran;
