-- fichier p_e_sortie.ads
-- D.F. juillet 2002 (ajout des Unbounded_String)
with Ada.Text_io, Ada.Strings.Unbounded;
package P_E_Sortie is
   use Ada.Text_Io, Ada.Strings.Unbounded;
   --==============================================
   -- Procdures d'entres/sorties sur les entiers prdfinis
   --==============================================

   procedure Ecrire (
         L_Entier : in     Integer ); 
   -- permet de visualiser un INTEGER  partir de la position
   -- initiale du curseur. Si l'on souhaite aller  la ligne ensuite
   -- il faut utiliser en plus la procdure A_LA_LIGNE

   procedure Lire (
         L_Entier :    out Integer ); 
   -- permet d'acqurir un INTEGER en base quelconque (2  16) avec
   -- validation (fait recommencer jusqu' ce la valeur soit valable)

   --===============================================
   -- Procdures d'entres/sorties sur les flottants prdfinis
   --===============================================

   procedure Ecrire (
         Le_Reel : in     Float ); 
   -- permet de visualiser un FLOAT sur la ligne  partir de la position
   -- initiale du curseur. Si l'on souhaite aller  la ligne ensuite
   -- il faut utiliser en plus la procdure A_LA_LIGNE.
   -- Le rel est crit sous la forme:
   -- signe, partie entire, point dcimal et partie dcimale
   -- le point dcimal est toujours prsent, 
   -- le signe + est remplac par un espace.
   -- Quant aux deux champs numriques ils suppriment les 
   -- zros non significatifs.

   procedure Lire (
         Le_Reel :    out Float ); 
   -- permet d'acqurir un FLOAT dans une base quelconque (2  16) avec
   -- validation (on recommence jusqu' ce que la valeur soit valable). 
   -- Le point dcimal est obligatoire  la saisie.

   --=================================================
   -- Procdures d'entres/sorties sur les caractres
   --=================================================

   procedure Ecrire (
         Carac : Character ) ; 
   -- permet de visualiser un caractre  partir de la position
   -- initiale du curseur. Si l'on souhaite aller  la ligne ensuite
   -- utiliser en plus la procdure A_LA_LIGNE

   procedure Lire (
         Carac :    out Character ); 
   -- permet d'acqurir un caractre unique. Lecture tamponne c'est-
   -- -dire que l'on peut effacer le caractre saisi d'o ncessit de
   -- terminer la saisie par un RC (appui sur la touche entre). Le 
   -- tampon est purg aprs la prise en compte de ce caractre.

   --============================================================
   -- Procdures d'entres/sorties sur les chanes de caractres
   -- On pourra lui prfrer plus tard les paquetages prdfinis
   --============================================================

   procedure Ecrire (
         La_Chaine : String ); 
   -- permet de visualiser une chane de caractres  partir 
   -- de la position initiale du curseur.

   procedure Lire (
         La_Chaine :    out String ); 
   -- permet de saisir une frappe de caractres termine par entre
   -- si le nombre de caractres est infrieur  la dimension du STRING
   -- pass en paramtre le complment est initialis  espace. 
   -- Le tampon est purg.

   procedure Lire (
         La_Chaine :    out Unbounded_String ); 
   -- permet de saisir une frappe de caractres termine par entre
   -- il n'y a pas de limite, ni problme de remplissage

   --=========================================================
   -- Procdures vider clavier et saut  la ligne sur l'cran
   --=========================================================

   procedure Vider_Tampon; 
   -- peu utile dans le contexte propos ici puisque toutes les saisies 
   -- sont purges. Permet cependant d'attendre la frappe de la touche
   -- entre. C'est une pause (voir ci-dessous) sans message.

   procedure A_La_Ligne (
         Nombre : Positive_Count := 1 ) renames New_Line; 
   -- sans commentaire

   procedure Pause; 
   -- affiche le message: "appuyez sur Entre pour continuer"
   -- et attend la frappe sur la touche entre.

   --==============================================================
   -- Transformation de FLOAT ou d'INTEGER en Chane de caractres
   --==============================================================

   function Image (
         L_Entier : in     Integer ) 
     return String; 
   -- c'est une "redfinition" de l'attribut c'est--dire INTEGER'IMAGE

   function Image (
         Le_Reel : in     Float ) 
     return String; 
   -- permet une amlioration de l'attribut FLOAT'IMAGE 
   -- l'image est celle dfinie dans la procdure ECRIRE avec FLOAT.

   -- permet des critures d'images d'objets de type diffrent ainsi:
   -- ECRIRE(IMAGE(...)&"...."&IMAGE(...)&"..." etc.);

   --=========================
   -- Spcial type discrets (pour les types numratifs et entiers)      
   --=========================
   -- Pour viter d'avoir  instancier (trop tt!) les sous-paquetages
   -- ADA.TEXT_IO.ENUMERATION_IO ou ADA.TEXT_IO.INTEGER_IO
   -- (l'exercice n'est pas difficile mais mythique !)
   -- on copiera la squence suivante en adaptant les identificateurs
   -- T_DISCRET et DISCRET au type discret et  la variable de ce type
   -- 
   -- loop
   --     declare
   --         CHAI : UNBOUNDED_STRING ;
   --     begin
   --         LIRE(CHAI);
   --         DISCRET := T_DISCRET'VALUE(TO_STRING(CHAIN));
   --         exit;
   --         exception when others =>
   --                     null; -- ou message ECRIRE("xxxxx");
   --     end;
   -- end loop;
   --
   --
end P_E_Sortie;

-- fin des spcifications du paquetage d'Entres-Sorties